@@ -291,7 +291,14 @@ class CustomResourceProvider:
         :param kind: Kind of this custom resource.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CustomResourceProvider.__init__)
+            def stub(
+                *,
+                api_version: builtins.str,
+                handler: "ICustomResourceProviderHandler",
+                kind: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument api_version", value=api_version, expected_type=type_hints["api_version"])
             check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
             check_type(argname="argument kind", value=kind, expected_type=type_hints["kind"])
@@ -374,7 +381,13 @@ class _ICustomResourceProviderHandlerProxy:
         :param spec: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ICustomResourceProviderHandler.apply)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                spec: typing.Any,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument spec", value=spec, expected_type=type_hints["spec"])
@@ -452,7 +465,13 @@ class OperatorProps:
         :param output_file: Where to write the synthesized output. Default: "/dev/stdout"
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(OperatorProps.__init__)
+            def stub(
+                *,
+                input_file: typing.Optional[builtins.str] = None,
+                output_file: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument input_file", value=input_file, expected_type=type_hints["input_file"])
             check_type(argname="argument output_file", value=output_file, expected_type=type_hints["output_file"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -512,7 +531,9 @@ class Server(metaclass=jsii.JSIIMeta, jsii_type="cdk8s-operator.Server"):
         :param port: The port to listen to. If not specified, the ``PORT`` environment variable will be used. If that's not specified an available port will be auto-selected.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Server.listen)
+            def stub(port: typing.Optional[jsii.Number] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         return typing.cast(jsii.Number, jsii.ainvoke(self, "listen", [port]))
 
@@ -528,7 +549,9 @@ class ServerProps:
         :param app_command: The command to execute in order to synthesize the CDK app.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ServerProps.__init__)
+            def stub(*, app_command: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument app_command", value=app_command, expected_type=type_hints["app_command"])
         self._values: typing.Dict[str, typing.Any] = {
             "app_command": app_command,
